==> dotclear-2.8.1.zip: dotclear/plugins/dcCKEditor/locales/fr/main.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['The configuration has been updated.'] = 'La configuration a été mise à jour.';
$GLOBALS['__l10n']['Settings'] = 'Options';
$GLOBALS['__l10n']['Plugin activation'] = 'Activation du plugin';
$GLOBALS['__l10n']['Enable dcCKEditor plugin'] = 'Activer le plugin dcCKEditor';
$GLOBALS['__l10n']['Options'] = 'Options';
$GLOBALS['__l10n']['Add alignment buttons'] = 'Ajouter les boutons d\'alignement';
$GLOBALS['__l10n']['Add lists buttons'] = 'Ajouter les boutons de listes';
$GLOBALS['__l10n']['Save configuration'] = 'Sauver la configuration';
$GLOBALS['__l10n']['Add text color button'] = 'Ajouter le bouton pour changer la couleur du texte';
$GLOBALS['__l10n']['Add collapse button'] = 'Ajouter le bouton pour masquer les boutons';
$GLOBALS['__l10n']['Add format selection'] = 'Ajouter le bouton pour ajouter les formats.';
$GLOBALS['__l10n']['Add table button'] = 'Ajouter le bouton pour ajouter des tableaux.';
$GLOBALS['__l10n']['Add clipboard buttons'] = 'Ajouter les boutons de copier/coller...';
$GLOBALS['__l10n']['Copy, Paste, Paste Text, Paste from Word'] = 'Copier, Coller, Coller sans mise en forme, Copier depuis word';
$GLOBALS['__l10n']['Advanced options'] = 'Options avancées';
$GLOBALS['__l10n']['Text areas to be used by CKEditor'] = 'Liste des blocs où utiliser CKEditor';
$GLOBALS['__l10n']['Comma separed list of textareas - jQuery selector. Defaut: '] = 'Listes d\'élements html à transformer avec CKEditor - C\'est une liste utilisée par jQuery. Défaut : ';
$GLOBALS['__l10n']['URL field cannot be empty.'] = 'L\'URL ne peut pas être vide.';
$GLOBALS['__l10n']['Disables the built-in spell checker if the browser provides one'] = 'Désactiver la correction orthographique fournie par le navigateur';

==> dotclear-2.13.1.zip: dotclear/plugins/dcCKEditor/locales/fr/main.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['The configuration has been updated.'] = 'La configuration a été mise à jour.';
$GLOBALS['__l10n']['Settings'] = 'Options';
$GLOBALS['__l10n']['Plugin activation'] = 'Activation du plugin';
$GLOBALS['__l10n']['Enable dcCKEditor plugin'] = 'Activer le plugin dcCKEditor';
$GLOBALS['__l10n']['Options'] = 'Options';
$GLOBALS['__l10n']['Add alignment buttons'] = 'Ajouter les boutons d\'alignement';
$GLOBALS['__l10n']['Add lists buttons'] = 'Ajouter les boutons de listes';
$GLOBALS['__l10n']['Save configuration'] = 'Sauver la configuration';
$GLOBALS['__l10n']['Add text color button'] = 'Ajouter le bouton pour changer la couleur du texte';
$GLOBALS['__l10n']['Add background text color button'] = 'Ajouter le bouton pour changer la couleur de fond du texte';
$GLOBALS['__l10n']['Add collapse button'] = 'Ajouter le bouton pour masquer les boutons';
$GLOBALS['__l10n']['Add format selection'] = 'Ajouter le bouton pour ajouter les formats.';
$GLOBALS['__l10n']['Add table button'] = 'Ajouter le bouton pour ajouter des tableaux.';
$GLOBALS['__l10n']['Add clipboard buttons'] = 'Ajouter les boutons de copier/coller...';
$GLOBALS['__l10n']['Copy, Paste, Paste Text, Paste from Word'] = 'Copier, Coller, Coller sans mise en forme, Copier depuis word';
$GLOBALS['__l10n']['Advanced options'] = 'Options avancées';
$GLOBALS['__l10n']['Text areas to be used by CKEditor'] = 'Liste des blocs où utiliser CKEditor';
$GLOBALS['__l10n']['Comma separed list of textareas - jQuery selector. Defaut: '] = 'Listes d\'élements html à transformer avec CKEditor - C\'est une liste utilisée par jQuery. Défaut : ';
$GLOBALS['__l10n']['URL field cannot be empty.'] = 'L\'URL ne peut pas être vide.';
$GLOBALS['__l10n']['Disables the built-in spell checker if the browser provides one'] = 'Désactiver la correction orthographique fournie par le navigateur';
